==> Mfuzz_2.2.0.zip: Mfuzz/doc/Mfuzz.R <==
###################################################
### chunk number 1: 
###################################################
  library(Mfuzz) 


###################################################
### chunk number 2: 
###################################################
  data(yeast) 


###################################################
### chunk number 3: 
###################################################
yeast.r <- filter.NA(yeast, thres=0.25)


###################################################
### chunk number 4: 
###################################################
yeast.f <- fill.NA(yeast.r,mode="mean")


###################################################
### chunk number 5:  eval=FALSE
###################################################
##   tmp <- filter.std(yeast.f,min.std=0)  


###################################################
### chunk number 6: 
###################################################
yeast.s <- standardise(yeast.f)


###################################################
### chunk number 7:  eval=FALSE
###################################################
##  cl <- mfuzz(yeast.s,c=16,m=1.25)
##  mfuzz.plot(yeast.s,cl=cl,mfrow=c(4,4),time.labels=seq(0,160,10))


###################################################
### chunk number 8:  eval=FALSE
###################################################
##    cl2 <- mfuzz(yeast.s,c=16,m=1.35)
##    mfuzz.plot(yeast.s,cl=cl2,mfrow=c(4,4),time.labels=seq(0,160,10))


###################################################
### chunk number 9:  eval=FALSE
###################################################
## O <- overlap(cl)
## Ptmp <- overlap.plot(cl,over=O,thres=0.05)


###################################################
### chunk number 10:  eval=FALSE
###################################################
## cl3 <- mfuzz(yeast.s,c=10,m=1.25)
## mfuzz.plot(yeast.s,cl=cl3,mfrow=c(3,4))
## O3 <- overlap(cl3)
## overlap.plot(cl3,over=O3,P=Ptmp,thres=0.05)


###################################################
### chunk number 11:  eval=FALSE
###################################################
## cl4 <- mfuzz(yeast.s,c=25,m=1.25)
## mfuzz.plot(yeast.s,cl=cl4,mfrow=c(5,5))
## O4 <- overlap(cl4)
## overlap.plot(cl4,over=O4,P=Ptmp,thres=0.05)

==> Mfuzz_2.8.0.zip: Mfuzz/doc/Mfuzz.R <==
###################################################
### chunk number 1: 
###################################################
#line 42 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpfJRIZE/R.INSTALL19235eb6/Mfuzz/inst/doc/Mfuzz.Rnw"
  library(Mfuzz) 


###################################################
### chunk number 2: 
###################################################
#line 54 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpfJRIZE/R.INSTALL19235eb6/Mfuzz/inst/doc/Mfuzz.Rnw"
  data(yeast) 


###################################################
### chunk number 3: 
###################################################
#line 63 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpfJRIZE/R.INSTALL19235eb6/Mfuzz/inst/doc/Mfuzz.Rnw"
yeast.r <- filter.NA(yeast, thres=0.25)


###################################################
### chunk number 4: 
###################################################
#line 73 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpfJRIZE/R.INSTALL19235eb6/Mfuzz/inst/doc/Mfuzz.Rnw"
yeast.f <- fill.NA(yeast.r,mode="mean")


###################################################
### chunk number 5:  eval=FALSE
###################################################
## #line 92 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpfJRIZE/R.INSTALL19235eb6/Mfuzz/inst/doc/Mfuzz.Rnw"
##   tmp <- filter.std(yeast.f,min.std=0)  


###################################################
### chunk number 6: 
###################################################
#line 116 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpfJRIZE/R.INSTALL19235eb6/Mfuzz/inst/doc/Mfuzz.Rnw"
yeast.s <- standardise(yeast.f)


###################################################
### chunk number 7:  eval=FALSE
###################################################
## #line 151 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpfJRIZE/R.INSTALL19235eb6/Mfuzz/inst/doc/Mfuzz.Rnw"
##  cl <- mfuzz(yeast.s,c=16,m=1.25)
##  mfuzz.plot(yeast.s,cl=cl,mfrow=c(4,4),time.labels=seq(0,160,10))


###################################################
### chunk number 8:  eval=FALSE
###################################################
## #line 212 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpfJRIZE/R.INSTALL19235eb6/Mfuzz/inst/doc/Mfuzz.Rnw"
##    cl2 <- mfuzz(yeast.s,c=16,m=1.35)
##    mfuzz.plot(yeast.s,cl=cl2,mfrow=c(4,4),time.labels=seq(0,160,10))


###################################################
### chunk number 9:  eval=FALSE
###################################################
## #line 243 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpfJRIZE/R.INSTALL19235eb6/Mfuzz/inst/doc/Mfuzz.Rnw"
## O <- overlap(cl)
## Ptmp <- overlap.plot(cl,over=O,thres=0.05)


###################################################
### chunk number 10:  eval=FALSE
###################################################
## #line 251 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpfJRIZE/R.INSTALL19235eb6/Mfuzz/inst/doc/Mfuzz.Rnw"
## cl3 <- mfuzz(yeast.s,c=10,m=1.25)
## mfuzz.plot(yeast.s,cl=cl3,mfrow=c(3,4))
## O3 <- overlap(cl3)
## overlap.plot(cl3,over=O3,P=Ptmp,thres=0.05)


###################################################
### chunk number 11:  eval=FALSE
###################################################
## #line 268 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpfJRIZE/R.INSTALL19235eb6/Mfuzz/inst/doc/Mfuzz.Rnw"
## cl4 <- mfuzz(yeast.s,c=25,m=1.25)
## mfuzz.plot(yeast.s,cl=cl4,mfrow=c(5,5))
## O4 <- overlap(cl4)
## overlap.plot(cl4,over=O4,P=Ptmp,thres=0.05)
